<template>
  <div class="full-page bg" element-loading-text="数据加载中..." element-loading-spinner="el-icon-loading"
    element-loading-background="rgba(255,255,255, 0.5)" v-loading.fullscreen.lock="markLoading">
    <div :class="['search-container', isAdvanced ? 'advanced-search' : '']">
      <el-form ref="form" :model="searchForm" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="试点项目名称">
              <el-input v-model="searchForm['PILOT_PROJECT_NAME_']" clearable placeholder="请输入试点项目名称"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="试点文件文号">
              <el-input v-model="searchForm['DOC_NO_']" clearable placeholder="请输入试点文件文号"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="专项小组">
              <el-select v-model="searchForm['group_Name_']" placeholder="请选择专项小组" style="width: 100%;" clearable>
                <el-option v-for="item in groupList" :key="item.id" :label="item.name" :value="item.value">
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="审核状态">
              <dict-select dictCode="ggsd_sjshzt" :hasDefaultOption="true" clearable v-model="searchForm['r.status_']"
                style="width: 100%" placeholder="请选择审核状态" />
            </el-form-item>
          </el-col>
          <el-col :span="2">
            <el-button icon="el-icon-search" type="primary" class="btn btn-plus" @click="handleSearch(1)">
              {{ this.$t('common.search') }}
            </el-button>
          </el-col>
          <el-col :span="2" class="search-action-btn">
            <el-link :underline="false" type="primary" @click="advanced">
              {{ isAdvanced ? '基础搜索' : '高级搜索' }}
            </el-link>
            <el-link :underline="false" type="danger" @click="clearSearchForm">
              重置
            </el-link>
          </el-col>
          <el-col :span="5">
            <el-form-item label="所属领域">
              <dict-select dictCode="ggbb_ssly" :hasDefaultOption="true" clearable v-model="searchForm['pilot_field_']"
                style="width: 100%" @select="(val, obj) => hanldeCommonSelect(val, obj, 'formInfo')"
                placeholder="请选择所属领域" />
            </el-form-item>
          </el-col>
          <!-- <el-col :span="5">
            <el-form-item label="所属跑道">
              <el-select v-model="searchForm['pilot_runway_']" style="width: 100%" clearable placeholder="请选择所属跑道">
                <el-option v-for="item in demandRunwaOoptionsForm" :key="item.value" :label="item.name"
                  :value="item.value">
                </el-option>
              </el-select>
            </el-form-item>
          </el-col> -->
          <el-col :span="5">
            <el-form-item label="推进状态">
              <dict-select dictCode="sjsd_tjzt" :hasDefaultOption="true" clearable v-model="searchForm['r.PROPULSIVE_STATUS_']"
                style="width: 100%" placeholder="请选择推进状态" />
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <el-row :gutter="10" :class="['main-table-container', 'flex', isAdvanced ? 'advanced-search-table' : '']">
      <el-col :span="24" class="table-container" ref="contentPanel" style="padding: 20px">
        <div style="margin-bottom: 10px" ref="btnPanel">
          <el-button icon="el-icon-plus" type="primary" class="btn btn-plus" @click="openDialog({}, '新增')">
            {{ this.$t('common.add') }}
          </el-button>
          <el-button slot="reference" icon="el-icon-delete" type="danger" class="btn btn-delete" @click="handleDelete"
            :disabled="deleteIds ? false : true">
            {{ this.$t('common.delete') }}
          </el-button>
        </div>
        <div :style="{ width: '100%', height: `${tableMaxHeight}` + 'px' }">
          <el-table stripe size="mini" v-loading="tableLoading" ref="multipleSelection" :data="tableData"
            :max-height="tableMaxHeight" :style="{ width: '100%' }" @selection-change="handleSelectionChange"
            :default-sort="{ prop: 'status', order: 'ascending' }">
            <el-table-column type="selection" width="55" align="center"></el-table-column>
            <el-table-column prop="pilotProjectName" show-overflow-tooltip min-width="250" label="试点项目名称" align="center">
            </el-table-column>
            <el-table-column prop="groupName" show-overflow-tooltip min-width="160" label="专项小组" align="center">
            </el-table-column>
            <el-table-column prop="docNo" show-overflow-tooltip min-width="220" label="试点文件文号" align="center">
            </el-table-column>
            <!-- <el-table-column :prop="'mainUnitName' || 'unitName'" show-overflow-tooltip min-width="120" label="责任单位"
              align="center">
              <template v-slot="{ row }">
                {{ row.mainUnitName || row.unitName }}
              </template>
            </el-table-column> -->
            <el-table-column prop="status" show-overflow-tooltip width="150" label="审核状态" align="center">
              <template v-slot="{ row }">
                <el-tag :type="row.status === 1 || row.status === 3 || row.status === 5 ? '' : row.status === 7
                  ? 'success'
                  : row.status === 2 || row.status === 4 || row.status === 6
                    ? 'danger'
                    : 'info'
                  ">
                  {{ getDictName('ggsd_sjshzt', row.status) }}
                </el-tag>
              </template>
            </el-table-column>
            <el-table-column show-overflow-tooltip min-width="150" align="center" fixed="right"
              :label="$t('common.operation')">
              <template v-slot="{ row }">
                <el-link v-if="row.status === 1 || row.status === 3 || row.status === 5
                  " icon="el-icon-view" type="primary" :underline="false" class="cloumn-btn"
                  @click="openDialog(row, '详情')">
                  详情
                </el-link>
                <el-link v-if="row.status === 0" icon="el-icon-s-check" type="primary" :underline="false"
                  class="cloumn-btn" @click="handleVerify(row)">
                  上报
                </el-link>
                <el-link v-if="row.status === 0
                  " icon="el-icon-edit" type="primary" :underline="false" class="cloumn-btn"
                  @click="openDialog(row, '编辑')">
                  编辑
                </el-link>
                <el-link v-if="row.status === 6 || row.status === 2 || row.status === 4 || row.status === 7
                  " icon="el-icon-refresh" type="primary" :underline="false" class="cloumn-btn"
                  @click="openDialog(row, '更新')">
                  更新
                </el-link>
                <el-link v-if="row.status === 1" icon="el-icon-refresh-left" type="danger" :underline="false"
                  class="cloumn-btn withdraw" @click="revocation(row)">
                  撤回
                </el-link>
              </template>
            </el-table-column>
          </el-table>
        </div>
        <pagination ref="paginationPanel" style="margin-top: 10px" :pageResult="pageResult"
          @size-change="handleSizeChange" @current-change="handleCurrentChange" />
      </el-col>
    </el-row>
    <MunicipalPilotDialog ref="municipalPilotDialog" @sendMsg="callData"></MunicipalPilotDialog>
    <detailDialog ref="detailDialog"></detailDialog>
  </div>
</template>
  
<script>
import pagination from '@/components/pagination'
import { TableMixin } from '@/mixins/tableMixin'
import MunicipalPilotDialog from './components/MunicipalPilotDialog.vue'
import detailDialog from './components/detailDialog'
import pilot from '@/api/pilotprojects'
import utils from '@/utils.js'
export default {
  name: 'MunicipalPilotEntry',
  components: {
    pagination,
    MunicipalPilotDialog,
    detailDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      markLoading: false,
      searchForm: {},
      tableMaxHeight: 400,
      tableData: [],
      pageResult: {
        page: 1,
        pageSize: 20,
        total: 0
      },
      reqData: {
        pageBean: {
          page: 1,
          pageSize: 20,
          showTotal: true
        }
      },
      tableLoading: false,
      deleteIds: '',
      treeData: [],
      groupList: []
    }
  },

  created() {
    this.getData(this.reqData)
    this.treeData = JSON.parse(sessionStorage.getItem('responsibilityTree'))
    this.groupList = utils.getDictItemsFromCache('zxxz')
    this.setPilotLevelList()
  },
  methods: {
    //获取数据
    getData(data) {
      this.tableLoading = true
      pilot.getTableData(data, false, res => {
        this.pageResult.total = res.total
        this.tableLoading = false
        this.tableData = res.rows
      })
    },

    // 查看详情 编辑  添加
    openDialog(item, title) {
      this.$refs.municipalPilotDialog.add(item, title)
    },
    callData() {
      this.handleSearch(this.pageResult.page)
    },
    // 过滤
    filterHandler(value, row, column) {
      return row.pilotLevel == value
    },
    // 上报
    handleVerify(item) {
      let data = {
        status: 1,
        id: item.recId
      }
      this.$confirm('确认上报吗？', this.$t('common.tips'), {
        confirmButtonText: this.$t('common.confirm'),
        cancelButtonText: this.$t('common.cancel'),
        type: 'success'
      }).then(() => {
        this.markLoading = true
        pilot.updateMunStatus(data, res => {
          if (res.state) {
            item.status = 1
            this.$message.success('上报成功')
          }
          this.markLoading = false
        })
      })
    },
    // 撤回
    revocation(item) {
      let data = {
        status: 0,
        id: item.recId
      }
      this.$confirm('确认执行撤销操作吗？', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'error'
      }).then(() => {
        this.markLoading = true
        data.approvalResults = 2
        pilot.updateMunStatus(data, res => {
          if (res.state) {
            this.$message.success('撤销操作成功')
            this.handleSearch(1)
          }
          this.markLoading = false
        })

      })
    },
    //获取删除数据id集合
    handleSelectionChange(val) {
      let arr = val.map(item => item.id)
      this.deleteIds = arr.join(',')
    },
    //删除
    handleDelete() {
      this.$confirm('确认删除吗？', this.$t('common.tips'), {
        confirmButtonText: this.$t('common.confirm'),
        cancelButtonText: this.$t('common.cancel'),
        type: 'error'
      }).then(() => {
        this.markLoading = true
        pilot.deleteMunPlit(this.deleteIds, false, res => {
          if (res.state) {
            this.getData(this.reqData)
            this.$message.success('删除成功')
            this.markLoading = false
          } else {
            this.markLoading = false
          }
        })
      })
    },

    getDictName(code, value) {
      return utils.getDictName(code, value)
    },
    handleSearch(page) {
      this.tableLoading = true
      let data = JSON.parse(JSON.stringify(this.reqData))
      let obj = JSON.parse(JSON.stringify(this.searchForm))
      let querys = []
      for (let i in obj) {
        if (obj[i]) {
          querys.push({
            group: 'main',
            operation:
              i == 'PILOT_PROJECT_NAME_' || i == 'DOC_NO_' ? 'LIKE' : 'EQUAL',
            parentGroup: '',
            property: i,
            relation: 'AND',
            value: obj[i]
          })
        }
      }
      data.querys = querys
      data.pageBean.page = page
      this.pageResult.page = page
      pilot.getTableData(data, false, res => {
        this.pageResult.total = res.total
        this.tableLoading = false
        this.tableData = res.rows
      })
    },

    handleCurrentChange(page) {
      this.reqData.pageBean = { ...this.reqData.pageBean, page }
      this.handleSearch(page)
    },
    handleSizeChange(pageSize) {
      this.reqData.pageBean = { ...this.reqData.pageBean, pageSize }
      this.handleSearch(1)
    }
  }
}
</script>
  
<style lang="scss" scoped>
.common-tree-container {
  height: calc(100% - 70px);
  margin-top: 0.52083vw;
  padding: 1.04167vw 1.04167vw;
  background-color: #fff;
  position: relative;
  box-sizing: border-box;
  overflow-y: auto;
  border-radius: 20px;
  box-shadow: 0px 0px 0.625vw 0 rgba(92, 102, 83, 0.2);
}

.container-head {
  display: flex;
  align-items: center;

  i {
    font-size: 16px;
    margin-left: 5px;
    font-weight: 600;
    cursor: pointer;
  }
}

.move-tree /deep/ .el-tree {
  height: 90%;
  overflow-y: auto;
  border: none;
}

.cloumn-btn {
  border: 1px solid #2761ff;
  padding: 3px 10px;
  border-radius: 5px;

  &:nth-child(1) {
    margin-right: 5px;
  }

  &:nth-child(1):hover {
    background-color: #2761ff;
    color: #fff;
  }

  &:nth-child(2):hover {
    background-color: #2761ff;
    color: #fff;
    border-color: #2761ff;
  }

  /deep/ i,
  span {
    font-size: 14px;
  }
}

/deep/ .el-tree-node__content {
  padding: 5px 0;
}

.qx-tag {
  cursor: pointer;
  user-select: none;
}

.search-container {
  /deep/ .el-form-item__label {
    line-height: 58px;
    white-space: nowrap !important;
  }
}

.el-dropdown-link {
  cursor: pointer;
  font-size: 0.72917vw;
  font-weight: bold;
  color: #3c4353;
}
</style>
  